## Summary

What's the [new hotness](https://youtu.be/ha-uagjJQ9k?t=17)?

### Why?

What is my [purpose](https://youtu.be/X7HmltUWXgs?t=52)?

### How?

But how?!

## Mantra

_Remember, "Slow is smooth, and smooth is fast"._

If you have any questions not answered by a quick readthrough of the [contributor guide](https://pysparkplug.mattefay.com/en/latest/contributor_guide.html), add them to this PR and submit it.
